@@ -2,14 +2,16 @@
 checkConstraint <-
 function(x, constr, byPat=TRUE, semSign=FALSE,
          sortBy=c("none", "observed", "compliance", "structure",
-                  "constraint", "patID", "deltaV", "deltaD", "dstMin")) {
+                  "constraint", "patID", "deltaV", "deltaD", "dstMin", "dstMinRel"),
+         interp=c("linear", "spline", "smooth"), ...) {
     UseMethod("checkConstraint")
 }
 
 checkConstraint.DVHs <-
 function(x, constr, byPat=TRUE, semSign=FALSE,
          sortBy=c("none", "observed", "compliance", "structure",
-                  "constraint", "patID", "deltaV", "deltaD", "dstMin")) {
+                  "constraint", "patID", "deltaV", "deltaD", "dstMin", "dstMinRel"),
+         interp=c("linear", "spline", "smooth"), ...) {
     x <- if(byPat) {
         setNames(list(x), x$structure)
     } else {
@@ -21,7 +23,7 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
 
     #NextMethod("checkConstraint")
     checkConstraint.DVHLst(x, constr=constr, byPat=byPat, semSign=semSign,
-                           sortBy=sortBy)
+                           sortBy=sortBy, interp=interp, ...)
 }
 
 ## with byPat=TRUE:  x is a list of DVHs (1 per structure)
@@ -29,7 +31,10 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
 checkConstraint.DVHLst <-
 function(x, constr, byPat=TRUE, semSign=FALSE,
          sortBy=c("none", "observed", "compliance", "structure",
-                  "constraint", "patID", "deltaV", "deltaD", "dstMin")) {
+                  "constraint", "patID", "deltaV", "deltaD", "dstMin", "dstMinRel"),
+         interp=c("linear", "spline", "smooth"), ...) {
+    interp <- match.arg(interp)
+
     ## make sure DVH list is organized as required for byPat
     if(is.null(attributes(x)$byPat) || attributes(x)$byPat != byPat) {
         stop(c("DVH list organization by-patient / by-structure",
@@ -45,6 +50,7 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
         valRelPC    <- 100 * (valDiff/valCmp)
         valDiffInv  <- smInv - valRef
         valRelPCInv <- 100 * (valDiffInv/valRef)
+        dstMinRel   <- 100 * dstInfo$dstMinRel
 
         deltaV   <- if(DV == "V") { valDiff  } else if(DV == "D") { valDiffInv  }
         deltaVpc <- if(DV == "V") { valRelPC } else if(DV == "D") { valRelPCInv }
@@ -53,48 +59,48 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
 
         list(observed=observed, deltaV=deltaV, deltaVpc=deltaVpc,
              deltaD=deltaD, deltaDpc=deltaDpc, valCmp=valCmp,
-             cmp=cmp, dstMin=dstInfo$dstMin, ptMinD=dstInfo$ptMinD,
-             ptMinV=dstInfo$ptMinV)
+             cmp=cmp, dstMin=dstInfo$dstMin, dstMinRel=dstMinRel,
+             ptMinD=dstInfo$ptMinD, ptMinV=dstInfo$ptMinV)
     }
 
     ## calculate metric and corresponding inverse metrics from given
     ## constraint set - vectorized in metrics
-    stridMetrics <- function(dvh, cnstr) {
+    stridMetrics <- function(dvh, cnstr, interp) {
         observed <- ifelse(cnstr$valid,
-                           unlist(getMetric(dvh, metric=cnstr$metric)),
+                           unlist(getMetric(dvh, metric=cnstr$metric, interp=interp, ...)),
                            NA_real_)
 
         
         ## inverse metrics
         smInv <- ifelse(cnstr$valid,
-                        unlist(getMetric(dvh, metric=cnstr$metricInv)),
+                        unlist(getMetric(dvh, metric=cnstr$metricInv, interp=interp, ...)),
                         NA_real_)
 
         names(observed) <- cnstr$constraint
         names(smInv)    <- cnstr$constraint
 
         ## distance constraint to closest point on DVH curve
-        Dcoord  <- with(cnstr, ifelse(DV == "D", valCmp, valRef))
-        Vcoord  <- with(cnstr, ifelse(DV == "V", valCmp, valRef))
+        Dcoord  <- ifelse(cnstr$DV == "D", cnstr$valCmp, cnstr$valRef)
+        Vcoord  <- ifelse(cnstr$DV == "V", cnstr$valCmp, cnstr$valRef)
         Dcoord  <- ifelse(cnstr$valid, Dcoord, NA_real_)
         Vcoord  <- ifelse(cnstr$valid, Vcoord, NA_real_)
-        volRel  <- with(cnstr, ((DV == "D") & (unitRef == "%")) |
-                               ((DV == "V") & (unitCmp == "%")))
-        doseRel <- with(cnstr, ((DV == "D") & (unitCmp == "%")) |
-                               ((DV == "V") & (unitRef == "%")))
+        volRel  <- ((cnstr$DV == "D") & (cnstr$unitRef == "%")) |
+                   ((cnstr$DV == "V") & (cnstr$unitCmp == "%"))
+        doseRel <- ((cnstr$DV == "D") & (cnstr$unitCmp == "%")) |
+                   ((cnstr$DV == "V") & (cnstr$unitRef == "%"))
 
         dstDVH <- dvhDistance(dvh,
                               DV=data.frame(D=Dcoord, V=Vcoord,
                                             volRel=volRel, doseRel=doseRel,
                                             unitRef=cnstr$unitRef, unitCmp=cnstr$unitCmp))
 
-        with(cnstr, Map(cmpMetrics, observed=observed, smInv=smInv,
-                        DV=DV, valCmp=valCmp, cmp=cmp, valRef=valRef,
-                        dstInfo=dstDVH))
+        Map(cmpMetrics, observed=observed, smInv=smInv,
+            DV=cnstr$DV, valCmp=cnstr$valCmp, cmp=cnstr$cmp, valRef=cnstr$valRef,
+            dstInfo=dstDVH)
     }
 
     ## get requested metrics for each structure/id
-    metrics <- Map(stridMetrics, xConstrSub$x, constrParse)
+    metrics <- Map(stridMetrics, xConstrSub$x, constrParse, interp=interp)
 
     ## check constraints
     leqGeq <- function(y) {
@@ -125,35 +131,53 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
 
     ## make sign of deltaD/deltaV semantically indicate compliance
     ## negative -> compliance, positive -> no compliance
+    ## compliance may be NA -> catch first to leave sign unchanged
+    complianceTF <- resDF$compliance
+    complianceTF[is.na(complianceTF)] <- TRUE
+
     if(semSign) {
-        resDF$deltaD   <- ifelse(resDF$compliance,
-                                 -1*resDF$deltaD  *sign(resDF$deltaD),
-                                    resDF$deltaD  *sign(resDF$deltaD))
-        resDF$deltaDpc <- ifelse(resDF$compliance,
-                                 -1*resDF$deltaDpc*sign(resDF$deltaDpc),
-                                    resDF$deltaDpc*sign(resDF$deltaDpc))
-        resDF$deltaV   <- ifelse(resDF$compliance,
-                                 -1*resDF$deltaV  *sign(resDF$deltaV),
-                                    resDF$deltaV  *sign(resDF$deltaV))
-        resDF$deltaVpc <- ifelse(resDF$compliance,
-                                 -1*resDF$deltaVpc*sign(resDF$deltaVpc),
-                                    resDF$deltaVpc*sign(resDF$deltaVpc))
-        resDF$dstMin   <- ifelse(resDF$compliance,
-                                 -1*resDF$dstMin  *sign(resDF$dstMin),
-                                    resDF$dstMin  *sign(resDF$dstMin))
+        resDF$deltaD    <- ifelse(complianceTF,
+                                  -1*resDF$deltaD   *sign(resDF$deltaD),
+                                     resDF$deltaD   *sign(resDF$deltaD))
+        resDF$deltaDpc  <- ifelse(complianceTF,
+                                  -1*resDF$deltaDpc *sign(resDF$deltaDpc),
+                                     resDF$deltaDpc *sign(resDF$deltaDpc))
+        resDF$deltaV    <- ifelse(complianceTF,
+                                  -1*resDF$deltaV   *sign(resDF$deltaV),
+                                     resDF$deltaV   *sign(resDF$deltaV))
+        resDF$deltaVpc  <- ifelse(complianceTF,
+                                  -1*resDF$deltaVpc *sign(resDF$deltaVpc),
+                                     resDF$deltaVpc *sign(resDF$deltaVpc))
+        resDF$dstMin    <- ifelse(complianceTF,
+                                  -1*resDF$dstMin   *sign(resDF$dstMin),
+                                     resDF$dstMin   *sign(resDF$dstMin))
+        resDF$dstMinRel <- ifelse(complianceTF,
+                                  -1*resDF$dstMinRel*sign(resDF$dstMinRel),
+                                     resDF$dstMinRel*sign(resDF$dstMinRel))
     }
 
     ## reorder variables to return
     if(byPat) {
         patID     <- xConstrSub$x[[1]]$patID
+        structure <- resDF$structure
     } else {
+        patID     <- resDF$patID
         structure <- xConstrSub$x[[1]]$structure
     }
-        
-    finDF <- with(resDF,
-                  data.frame(patID, structure, constraint, observed, compliance,
-                             deltaV, deltaVpc, deltaD, deltaDpc, dstMin, ptMinD, ptMinV,
-                             stringsAsFactors=FALSE))
+
+    finDF <- data.frame(patID, structure,
+                        constraint=resDF$constraint,
+                        observed=resDF$observed,
+                        compliance=resDF$compliance,
+                        deltaV=resDF$deltaV,
+                        deltaVpc=resDF$deltaVpc,
+                        deltaD=resDF$deltaD,
+                        deltaDpc=resDF$deltaDpc,
+                        dstMin=resDF$dstMin,
+                        dstMinRel=resDF$dstMinRel,
+                        ptMinD=resDF$ptMinD,
+                        ptMinV=resDF$ptMinV,
+                        stringsAsFactors=FALSE)
 
     ## sort
     if(!("none" %in% sortBy)) {
@@ -169,7 +193,10 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
 checkConstraint.DVHLstLst <-
 function(x, constr, byPat=TRUE, semSign=FALSE,
          sortBy=c("none", "observed", "compliance", "structure",
-                  "constraint", "patID", "deltaV", "deltaD", "dstMin")) {
+                  "constraint", "patID", "deltaV", "deltaD", "dstMin", "dstMinRel"),
+         interp=c("linear", "spline", "smooth"), ...) {
+
+    interp <- match.arg(interp)
 
     ## re-organize x into by-patient or by-structure form if necessary
     isByPat <- attributes(x)$byPat
@@ -183,9 +210,14 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
     xConstrSub <- harmoConstrDVH(xRO, constr=constr, byPat=byPat)
 
     ## check the constraints
-    res <- Map(checkConstraint,
-               x=xConstrSub$x, constr=xConstrSub$constr,
-               byPat=byPat, semSign=semSign)
+    dots <- list(...)
+    args <- list(f=checkConstraint,
+                 x=xConstrSub$x,
+                 constr=xConstrSub$constr,
+                 byPat=byPat,
+                 semSign=semSign,
+                 interp=interp)
+    res <- do.call("Map", c(args, dots))
 
     ## transform into data frame
     resL    <- melt(res, id.vars=c("patID", "structure", "constraint", "compliance"))
@@ -194,9 +226,20 @@ function(x, constr, byPat=TRUE, semSign=FALSE,
                      value.var="value")
 
     ## reorder variables to return
-    finDF <- with(resDF, data.frame(patID, structure, constraint, observed, compliance,
-                                    deltaV, deltaVpc, deltaD, deltaDpc,
-                                    dstMin, ptMinD, ptMinV, stringsAsFactors=FALSE))
+    finDF <- data.frame(patID=resDF$patID,
+                        structure=resDF$structure,
+                        constraint=resDF$constraint,
+                        observed=resDF$observed,
+                        compliance=resDF$compliance,
+                        deltaV=resDF$deltaV,
+                        deltaVpc=resDF$deltaVpc,
+                        deltaD=resDF$deltaD,
+                        deltaDpc=resDF$deltaDpc,
+                        dstMin=resDF$dstMin,
+                        dstMinRel=resDF$dstMinRel,
+                        ptMinD=resDF$ptMinD,
+                        ptMinV=resDF$ptMinV,
+                        stringsAsFactors=FALSE)
 
     ## sort
     if(!("none" %in% sortBy)) {
