@@ -1,6 +1,6 @@
 #####---------------------------------------------------------------------------
-## parse character vector from Eclipse DVH file
-parseMasterplan <- function(x, planInfo=FALSE) {
+## parse character vector from Masterplan DVH file
+parseMasterplan <- function(x, planInfo=FALSE, courseAsID=FALSE) {
     planInfo <- as.character(planInfo)
 
     ## function to extract one information element from a number of lines
@@ -91,7 +91,7 @@ parseMasterplan <- function(x, planInfo=FALSE) {
     }
 
     ## extract DVH from one structure section and store in a list
-    ## with DVH itself as a data frame
+    ## with DVH itself as a matrix
     getDVH <- function(strct, info) {
         ## extract information from info list
         doseRx    <- info$doseRx
