@@ -17,11 +17,14 @@ shinyUI(fluidPage(
                 conditionalPanel(condition="input.DVHin == '2'",
                                  h5("Upload DVH file: "),
                                  radioButtons("DVHtype", "DVH file format:",
-                                              list("Eclipse"=1, "CadPlan"=2, "MasterPlan"=3, "Pinnacle3"=4)),
+                                              list("Eclipse"=1, "CadPlan"=2, "MasterPlan"=3,
+                                                   "Pinnacle3"=4, "Monaco"=5, "HiArt"=6)),
                                  fileInput("DVHupload", "Select DVH file:", multiple=TRUE),
                                  radioButtons("DVHplanInfo", "Information encoded in plan:",
                                               list("None"=1, "Prescribed dose"=2)),
-                                 checkboxInput("DVHadd", "Add to existing data", FALSE)),
+                                 checkboxGroupInput("DVHreadOpts", label=NULL,
+                                                    choices=c("Add to existing data"="DVHadd",
+                                                              "Use Course for ID"="DVHcourse"))),
                 actionButton("applyData", "Apply"),
                 radioButtons("DVHverbose", "",
                              list("Short info on DVHs"=1,
